Documentation
¶
Index ¶
- func Contains(t *testing.T, container any, key any, msg ...any)
- func Empty(t *testing.T, v any, msg ...any)
- func Equal(t *testing.T, expected, got any, msg ...any)
- func EqualError(t *testing.T, expected, err error, msg ...any)
- func Error(t *testing.T, err error, msg ...any)
- func False(t *testing.T, value bool, msg ...any)
- func Nil(t *testing.T, v any, msg ...any)
- func NoError(t *testing.T, err error, msg ...any)
- func NotEqual(t *testing.T, expected, got any, msg ...any)
- func NotNil(t *testing.T, v any, msg ...any)
- func True(t *testing.T, value bool, msg ...any)
- func WithinDuration(t *testing.T, expected, actual time.Time, delta time.Duration, msg ...any)
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func Contains ¶
Contains asserts that the given container contains the specified key. It supports string (substring check) and map types.
func Empty ¶
Empty asserts that the given value is empty, nil, or has zero length. It fails the test if the value is not empty. Optionally, you can provide a custom message.
func EqualError ¶
EqualError asserts that err is not nil and its Error() matches expected.
Types ¶
This section is empty.
Click to show internal directories.
Click to hide internal directories.